$ErrorActionPreference="Stop"


function GetStatus([string]$service) {
  $ErrorActionPreference="Continue"
  $str = & $NSSM status $service 2> $null
  $ErrorActionPreference="Stop"

  # Strings returned from a command like nssm.exe have extra whitespace between each
  # character if assigned to a powershell var -- clear those out.
  $str -replace "`0", ""
}

function LogWrite([string]$logString) {
    $currentTime = Get-Date -Format "yyyy-MM-dd hh:mm:ss"
    Add-Content $LOG_FILE "[$currentTime] INFO $logString`n"
    Write-Host $logString
}

$RIGHTLINK_DIR        = "$env:ProgramFiles\RightScale\RightLink"
$RIGHTNETWORK_DIR     = "$env:ProgramFiles\RightScale\RightNetwork"
$LOG_DIR              = "$RIGHTNETWORK_DIR\Logs"
$LOG_FILE             = "$LOG_DIR\rightscale_network.log"
# We reuse RightLink's nssm - multiple versions may cause issues
$NSSM                 = "$RIGHTLINK_DIR\nssm.exe"
$RIGHTNETWORK         = "$RIGHTNETWORK_DIR\rightnetwork.ps1"
$INSTALLER_DIR        = split-path -parent $MyInvocation.MyCommand.Definition

# If RightLink directory and logs doesn't exist then create it
New-Item -Path $RIGHTNETWORK_DIR -Type Directory -Force | Out-Null
New-Item -Path $LOG_DIR -Type Directory -Force | Out-Null

# If log files don't exist then create them and the directory
if (!(Test-Path -Path $LOG_FILE)) {
  New-Item -Path $LOG_FILE -Type File -Force | Out-Null
}

if (!(Test-Path -Path $RIGHTLINK_DIR)) {
  throw "RightLink 10 must be installed."
}

$status = GetStatus('RightScaleuserdata')
if (!($status -like "SERVICE_*")) {
  throw "Could not find RightScaleUserData service, RightLink 10 must be installed."
}

Copy-Item -Recurse -Force "$INSTALLER_DIR/*" -Destination "$RIGHTNETWORK_DIR"

$status = GetStatus('RightScaleNetwork')
if (!($status -like "SERVICE_*")) {
  LogWrite "Creating RightScale Network service"
  & $NSSM install RightScaleNetwork "C:\Windows\System32\WindowsPowerShell\v1.0\powershell.exe" "-ExecutionPolicy Bypass -File `"`"`"$RIGHTNETWORK`"`"`""
  # Treat this as a oneshot and don't restart
  & $NSSM set RightScaleNetwork AppExit Default Exit
}

& $NSSM set RightScaleUserData Start SERVICE_DEMAND_START
